rivium_trace_flutter_sdk library
Classes
- CrashDetector
- Utility for detecting crashes from previous app sessions (mobile only)
- LogEntry
- A single log entry to be sent to RiviumTrace
- LogService
- Service for batching and sending logs to RiviumTrace
- OfflineStorageService
- Service for storing errors offline when network is unavailable
- PerformanceHttpClient
- HTTP client that tracks performance spans and sends them to RiviumTrace APM
- PerformanceSpan
- Performance span model for APM tracking
- PerformanceTracker
- Helper class for tracking performance of custom operations
- RiviumTrace
- Main RiviumTrace client for error tracking
- RiviumTraceBreadcrumbs
- In-memory breadcrumb tracking service Breadcrumbs are stored in memory only and are included with real-time error reports
- RiviumTraceConfig
- Configuration options for RiviumTrace SDK
- RiviumTraceError
- Represents an error captured by RiviumTrace
- RiviumTraceHttpClient
- HTTP client wrapper that automatically tracks HTTP requests as breadcrumbs
- Navigator observer for RiviumTrace to track current route/page
Enums
- BreadcrumbType
- Breadcrumb types for categorizing user actions
- LogLevel
- Log level for RiviumTrace logging
- MessageLevel
- RiviumTraceLogLevel
- Log level for RiviumTrace SDK
- SpanStatus
- Status of a performance span
Extensions
- PerformanceHttpClientExtension on Client
- Extension to wrap an existing http.Client with performance tracking
- RiviumTraceHttpClientExtension on Client
- Extension to easily wrap an existing http.Client with RiviumTrace tracking
Typedefs
- RiviumTraceLogCallback = void Function(RiviumTraceLogLevel level, String message, Object? error, StackTrace? stackTrace)
- Callback type for custom log handlers