PerformanceHttpClient class
HTTP client that tracks performance spans and sends them to RiviumTrace APM
Usage:
final client = PerformanceHttpClient(
apiKey: 'your-api-key',
environment: 'production',
);
final response = await client.get(Uri.parse('https://api.example.com/data'));
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
Uri url, {Map< String, String> ? headers, Object? body, Encoding? encoding}) → Future<Response> -
Sends an HTTP DELETE request with the given headers to the given URL.
inherited
-
flush(
) → Future< void> - Force flush any buffered spans
-
get(
Uri url, {Map< String, String> ? headers}) → Future<Response> -
Sends an HTTP GET request with the given headers to the given URL.
inherited
-
head(
Uri url, {Map< String, String> ? headers}) → Future<Response> -
Sends an HTTP HEAD request with the given headers to the given URL.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
Uri url, {Map< String, String> ? headers, Object? body, Encoding? encoding}) → Future<Response> -
Sends an HTTP PATCH request with the given headers and body to the given
URL.
inherited
-
post(
Uri url, {Map< String, String> ? headers, Object? body, Encoding? encoding}) → Future<Response> -
Sends an HTTP POST request with the given headers and body to the given
URL.
inherited
-
put(
Uri url, {Map< String, String> ? headers, Object? body, Encoding? encoding}) → Future<Response> -
Sends an HTTP PUT request with the given headers and body to the given
URL.
inherited
-
read(
Uri url, {Map< String, String> ? headers}) → Future<String> -
Sends an HTTP GET request with the given headers to the given URL and
returns a Future that completes to the body of the response as a String.
inherited
-
readBytes(
Uri url, {Map< String, String> ? headers}) → Future<Uint8List> -
Sends an HTTP GET request with the given headers to the given URL and
returns a Future that completes to the body of the response as a list of
bytes.
inherited
-
send(
BaseRequest request) → Future< StreamedResponse> - Sends an HTTP request and asynchronously returns the response.
-
toString(
) → String -
A string representation of this object.
inherited
-
withPerformanceTracking(
{required String apiKey, String? environment, String? releaseVersion, String? platform, bool addBreadcrumbs = true, Set< String> ? excludedHosts, double minDurationMs = 0}) → PerformanceHttpClient -
Available on Client, provided by the PerformanceHttpClientExtension extension
Wrap this client with RiviumTrace performance tracking -
withRiviumTrace(
{bool captureErrors = true, Set< String> ? excludedHosts}) → RiviumTraceHttpClient -
Available on Client, provided by the RiviumTraceHttpClientExtension extension
Wrap this client with RiviumTrace HTTP tracking
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited